@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.010000';
+$MetaCPAN::Client::VERSION = '1.011000';
 use Moo;
 use Carp;
 
@@ -159,7 +159,7 @@ sub all {
     my $type   = shift;
     my $params = shift;
 
-    grep { $type eq $_ } qw/ authors distributions modules releases /
+    grep { $type eq $_ } qw/ authors distributions modules releases favorites /
         or croak "all: unsupported type";
     $type =~ s/s$//;
 
@@ -344,7 +344,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.010000
+version 1.011000
 
 =head1 SYNOPSIS
 
@@ -490,7 +490,7 @@ formats (html, plain, x_pod & x_markdown).
 
 =head2 all
 
-Retrieve all matches for authors/modules/distributions or releases.
+Retrieve all matches for authors/modules/distributions/favorites or releases.
 
     my $all_releases = $mcpan->all('releases')
 
