@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.010000';
+$MetaCPAN::Client::Request::VERSION = '1.011000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -144,7 +144,8 @@ sub _build_body {
 
     return +{
         query => $query,
-        _read_filters($params)
+        _read_filters($params),
+        _read_facets($params)
     };
 }
 
@@ -154,6 +155,15 @@ my %key2es = (
     not    => 'must_not',
 );
 
+sub _read_facets {
+    my $params = shift;
+
+    my $facets = delete $params->{facets};
+    ref($facets) or return ();
+
+    return ( facets => $facets );
+}
+
 sub _read_filters {
     my $params = shift;
 
@@ -221,7 +231,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.010000
+version 1.011000
 
 =head1 ATTRIBUTES
 
